.. image:: https://github.com/ihmeuw-msca/stagemodel/workflows/python-build/badge.svg
    :target: https://github.com/ihmeuw-msca/stagemodel/actions

Stage Model
===========

This is a package for stage-wise model.
Used for Goal Keepers 2020 project.
